@@ -10,4 +10,6 @@ class ConfigHelper:
 
     @classmethod
     def show_status(self, text: str, r: Response):
-        Logger.write(f"[{'API':5s}] {text:30s} [{r.status_code}] {r.reason}")
+        reason = r.reason if r.status_code == 200 else r.content.decode("ascii")
+
+        Logger.write(f"[{'API':5s}] {text:30s} [{r.status_code}] {reason}")
