@@ -1,4 +1,5 @@
 import json
+from typing import Tuple
 
 import requests
 
@@ -66,24 +67,27 @@ class SoozAccess(object):
     def __exit__(self, *args, **kwargs):
         self.users.logout()
 
-    @property
-    def user_id(self):
-        _, r = self.users.login()
-        if r.status_code == 200:
-            id = json.loads(r.content.decode("utf-8"))["id"]
-            r = self.users.logout()
-            return id
+    # @property
+    # def user_id(self):
+    #     _, r = self.users.login()
+    #     if r.status_code == 200:
+    #         id = json.loads(r.content.decode("utf-8"))["id"]
+    #         r = self.users.logout()
+    #         return id
 
-        _, r = self.users.post_user()
-        if r.status_code == 200:
-            id = json.loads(r.content.decode("utf-8"))["id"]
-            return id
+    #     _, r = self.users.post_user()
+    #     if r.status_code == 200:
+    #         id = json.loads(r.content.decode("utf-8"))["id"]
+    #         return id
 
-        return None
+    #     return None
 
     @classmethod
     def prepare_users(cls, group_name: str, users: list[str]):
-        id_list = [SoozAccess(name, name).user_id for name in users]
+        id_list = []
+        for name in users:
+            with SoozAccess(name, name) as user:
+                id_list.append(user.users.user_id)
 
         # create group invitations from admin account
         with SoozAccess("admin_dev", "admin_dev") as admin:
