@@ -12,6 +12,7 @@ class UserHelper:
         self.session = session
         self.name = name
         self.token = token
+        self.user_id = None
 
     def post_user(self, entreprise_id: int = 1) -> Tuple[dict, Response]:
         """Create a user."""
@@ -83,6 +84,7 @@ class UserHelper:
             pass
         else:
             content = json.loads(r.content.decode("utf-8"))
+            self.user_id = content["id"]
         finally:
             ConfigHelper.show_status(f"*{self.name}* Login", r)
 
@@ -95,6 +97,8 @@ class UserHelper:
             r.raise_for_status()
         except HTTPError as e:
             pass
+        else:
+            self.user_id = None
         finally:
             ConfigHelper.show_status(f"*{self.name}* Logout", r)
 
